@@ -3,22 +3,19 @@ import logging
 import signal
 import traceback
 from collections import defaultdict, namedtuple, OrderedDict
-from pyramid.compat import text_type, string_types, NativeIO
+from pyramid.compat import NativeIO
 from pyramid.registry import Introspectable
 from pyramid.threadlocal import get_current_registry
-from zope.interface import implementedBy
-from zope.interface.interfaces import IObjectEvent
 
 import venusian
 from venusian.advice import getFrameInfo
 
 ATTACH_ATTR = '__ptah_actions__'
-ID_ADAPTER = 'ptah.config:adapter'
-ID_SUBSCRIBER = 'ptah.config:subscriber'
+ID_SUBSCRIBER = 'ptah:subscriber'
 
 __all__ = ('initialize', 'get_cfg_storage', 'StopException',
-           'event', 'adapter', 'subscriber', 'shutdown', 'shutdown_handler',
-           'Action', 'ClassAction', 'DirectiveInfo')
+           'event', 'subscriber', 'shutdown', 'shutdown_handler',
+           'Action', 'DirectiveInfo')
 
 log = logging.getLogger('ptah')
 
@@ -76,35 +73,6 @@ def pyramid_get_cfg_storage(config, id):
     return get_cfg_storage(id, config.registry)
 
 
-def adapter(*args, **kw):
-    """ Register adapter """
-    info = DirectiveInfo()
-
-    required = tuple(args)
-    name = kw.get('name', '')
-
-    def wrapper(func):
-        discr = (ID_ADAPTER, required, _getProvides(func), name)
-
-        intr = Introspectable(ID_ADAPTER, discr, 'Adapter', ID_ADAPTER)
-        intr['name'] = name
-        intr['required'] = required
-        intr['adapter'] = func
-        intr['codeinfo'] = info.codeinfo
-
-        def _register(cfg, name, func, required):
-            cfg.registry.registerAdapter(func, required, name=name)
-
-        info.attach(
-            Action(
-                _register, (name, func, required),
-                discriminator = discr, introspectables = (intr,))
-            )
-        return func
-
-    return wrapper
-
-
 def subscriber(*args):
     """ Register event subscriber. """
     info = DirectiveInfo(allowed_scope=('module', 'function call'))
@@ -113,7 +81,8 @@ def subscriber(*args):
         required = tuple(args)
         discr = (ID_SUBSCRIBER, func, required)
 
-        intr = Introspectable(ID_SUBSCRIBER, discr, 'Subscriber', ID_SUBSCRIBER)
+        intr = Introspectable(
+            ID_SUBSCRIBER, discr, 'Subscriber', 'ptah-subscriber')
         intr['required'] = required
         intr['handler'] = func
         intr['codeinfo'] = info.codeinfo
@@ -131,16 +100,6 @@ def subscriber(*args):
     return wrapper
 
 
-def _getProvides(factory):
-    p = list(implementedBy(factory))
-    if len(p) == 1:
-        return p[0]
-    else:
-        raise TypeError(
-            "The adapter factory doesn't implement a single interface "
-            "and no provided interface was specified.")
-
-
 class Action(object):
 
     hash = None
@@ -172,16 +131,6 @@ class Action(object):
                 raise
 
 
-class ClassAction(Action): # pragma: no cover
-
-    def __call__(self, cfg):
-        try:
-            self.callable(cfg, self.info.context, *self.args, **self.kw)
-        except:
-            log.exception(self.discriminator)
-            raise
-
-
 CodeInfo = namedtuple('Codeinfo', 'filename lineno function source module')
 
 
@@ -251,13 +200,13 @@ class DirectiveInfo(object):
                 introspectables=action.introspectables,
                 order=action.order)
 
-        venusian.attach(data, callback, category='ptah', depth=depth+1)
-
         if cfg is not None:
             cfg.action(
                 action.discriminator,
                 self._runaction, (action, cfg),
                 introspectables=action.introspectables, order=action.order)
+        else:
+            venusian.attach(data, callback, category='ptah', depth=depth+1)
 
     def __repr__(self):
         filename, line, function, source, module = self.codeinfo
