@@ -1,13 +1,12 @@
 """ introspect module """
-import urllib
-from zope.interface import Interface
+import player
+from player import RendererNotFound
 from pyramid.view import view_config
-from pyramid.compat import string_types, url_unquote
-from pyramid.interfaces import IIntrospectable
+from pyramid.compat import url_unquote
 
 import ptah
-from ptah.view import ISnippet
 from ptah.manage import get_manage_url
+from pform.directives import ID_PREVIEW
 
 
 @ptah.manage.module('introspect')
@@ -36,31 +35,25 @@ class Introspector(object):
 
 @view_config(
     context=IntrospectModule, wrapper=ptah.wrap_layout(),
-    renderer='ptah.manage:templates/introspect.pt')
+    renderer='ptah-manage:introspect.lt')
 class MainView(ptah.View):
     __doc__ = 'Introspection module view.'
 
     def update(self):
+        registry = self.request.registry
+        self.categories = registry.introspector.categories()
         self.manage_url = '{0}/introspect'.format(get_manage_url(self.request))
 
-        self.renderers = sorted(
-            (self.request.registry.adapters.lookupAll(
-                (IIntrospectable, Interface), ISnippet)),
-            key = lambda item: item[1].view.title)
-
 
 @view_config(
     context=Introspector, wrapper=ptah.wrap_layout(),
-    renderer='ptah.manage:templates/introspect-intr.pt')
+    renderer='ptah-manage:introspect-intr.lt')
 class IntrospectorView(ptah.View):
 
     def update(self):
         name = self.context.name
         registry = self.request.registry
 
-        self.renderer = registry.adapters.lookup(
-            (IIntrospectable, Interface), ISnippet, name=name)
-
         self.intrs = sorted(
             (item['introspectable'] for item in
              registry.introspector.get_category(name)),
@@ -68,7 +61,35 @@ class IntrospectorView(ptah.View):
 
         self.manage_url = '{0}/introspect'.format(get_manage_url(self.request))
 
-        self.renderers = sorted(
-            (registry.adapters.lookupAll(
-                (IIntrospectable, Interface), ISnippet)),
-            key = lambda item: item[1].view.title)
+        self.categories = registry.introspector.categories()
+
+    def render_intr(self, intr):
+        try:
+            return self.request.render_tmpl(
+                'ptah-intr:%s'%intr.type_name, intr,
+                manage_url = self.manage_url, rst_to_html = ptah.rst_to_html)
+        except RendererNotFound:
+            return self.request.render_tmpl(
+                'ptah-intr:ptah-default', intr,
+                manage_url = self.manage_url, rst_to_html = ptah.rst_to_html)
+
+
+@player.tmpl_filter('ptah-intr:pform-field')
+def tmpl_formfield(context, request):
+    return {'previews': request.registry[ID_PREVIEW]}
+
+
+@player.tmpl_filter('ptah-intr:ptah-subscriber')
+def tmpl_subscriber(intr, request):
+    handler = intr['handler']
+    required = intr['required']
+    factoryInfo = '%s.%s'%(intr['codeinfo'].module, handler.__name__)
+
+    if len(required) > 1: # pragma: no cover
+        obj = required[0]
+        klass = required[1]
+    else:
+        obj = None
+        klass = required[0]
+
+    return dict(factoryInfo=factoryInfo, obj=obj, klass=klass)
