@@ -1,11 +1,10 @@
-import inspect
 from zope.interface import providedBy
 from pyramid.view import view_config
 from pyramid.interfaces import IView, IViewClassifier
 from pyramid.httpexceptions import HTTPNotFound
 
 
-@view_config('layout-preview.html')
+@view_config(name='layout-preview.html')
 def layoutPreview(context, request):
     view_name = request.GET.get('view', '')
 
