@@ -50,7 +50,8 @@ def module(name):
 
     def wrapper(cls):
         discr = (MANAGE_ID, name)
-        intr = config.Introspectable(MANAGE_ID, discr, cls.title, MANAGE_ID)
+        intr = config.Introspectable(
+            MANAGE_ID, discr, cls.title, 'ptah-managemodule')
         intr['name'] = name
         intr['factory'] = cls
         intr['codeinfo'] = info.codeinfo
@@ -150,18 +151,6 @@ class PtahManageRoute(object):
         raise KeyError(key)
 
 
-ptah.layout.register(
-    '', PtahManageRoute, root=PtahManageRoute, parent='ptah-manage',
-    renderer="ptah.manage:templates/ptah-layout.pt")
-
-ptah.layout.register(
-    'ptah-page', PtahManageRoute, root=PtahManageRoute, parent='ptah-manage',
-    renderer="ptah.manage:templates/ptah-layout.pt")
-
-@ptah.layout(
-    'ptah-manage', PtahManageRoute, root=PtahManageRoute,
-    renderer="ptah.manage:templates/ptah-manage.pt")
-
 class LayoutManage(ptah.View):
     """ Base layout for ptah manage """
 
@@ -180,8 +169,8 @@ class LayoutManage(ptah.View):
 
 
 @view_config(
-    context=PtahManageRoute, wrapper = ptah.wrap_layout(),
-    renderer = 'ptah.manage:templates/manage.pt')
+    context=PtahManageRoute, wrapper=ptah.wrap_layout(),
+    renderer='ptah-manage:manage.lt')
 
 class ManageView(ptah.View):
     """List ptah modules"""
