@@ -13,7 +13,7 @@ class PermissionsModule(ptah.manage.PtahModule):
 
 @view_config(
     context=PermissionsModule, wrapper=ptah.wrap_layout(),
-    renderer='ptah.manage:templates/permissions.pt')
+    renderer='ptah-manage:permissions.lt')
 class PermissionsView(ptah.View):
     """ Permissions module default view """
 
@@ -29,10 +29,10 @@ class PermissionsView(ptah.View):
 
 
 @view_config(
-    'roles.html',
+    name='roles.html',
     context=PermissionsModule,
     wrapper=ptah.wrap_layout(),
-    renderer='ptah.manage:templates/roles.pt')
+    renderer='ptah-manage:roles.lt')
 
 class RolesView(ptah.View):
     """ Roles view for permissions manage module """
