@@ -1,6 +1,6 @@
 import ptah
-from ptah import form, config
-from ptah.form.field import PREVIEW_ID
+import pform
+from pform.directives import ID_PREVIEW
 from ptah.manage import fieldpreviews
 from ptah.testing import PtahTestCase
 from pyramid.testing import DummyRequest
@@ -10,8 +10,8 @@ from pyramid.view import render_view_to_response
 class TestFieldPreviews(PtahTestCase):
 
     def test_multiChoicePreview(self):
-        previews = config.get_cfg_storage(PREVIEW_ID)
-        self.assertIs(previews[form.MultiChoiceField],
+        previews = self.registry[ID_PREVIEW]
+        self.assertIs(previews[pform.MultiChoiceField],
                       fieldpreviews.multiChoicePreview)
 
         request = DummyRequest()
@@ -19,8 +19,8 @@ class TestFieldPreviews(PtahTestCase):
         self.assertIn('Multi choice field', html)
 
     def test_choicePreview(self):
-        previews = config.get_cfg_storage(PREVIEW_ID)
-        self.assertIs(previews[form.ChoiceField],
+        previews = self.registry[ID_PREVIEW]
+        self.assertIs(previews[pform.ChoiceField],
                       fieldpreviews.choicePreview)
 
         request = DummyRequest()
@@ -28,8 +28,8 @@ class TestFieldPreviews(PtahTestCase):
         self.assertIn('Choice field', html)
 
     def test_boolPreview(self):
-        previews = config.get_cfg_storage(PREVIEW_ID)
-        self.assertIs(previews[form.BoolField],
+        previews = self.registry[ID_PREVIEW]
+        self.assertIs(previews[pform.BoolField],
                       fieldpreviews.boolPreview)
 
         request = DummyRequest()
@@ -37,8 +37,8 @@ class TestFieldPreviews(PtahTestCase):
         self.assertIn('Boolean field', html)
 
     def test_radioPreview(self):
-        previews = config.get_cfg_storage(PREVIEW_ID)
-        self.assertIs(previews[form.RadioField],
+        previews = self.registry[ID_PREVIEW]
+        self.assertIs(previews[pform.RadioField],
                       fieldpreviews.radioPreview)
 
         request = DummyRequest()
@@ -46,8 +46,8 @@ class TestFieldPreviews(PtahTestCase):
         self.assertIn('Radio field', html)
 
     def test_textareaPreview(self):
-        previews = config.get_cfg_storage(PREVIEW_ID)
-        self.assertIs(previews[form.TextAreaField],
+        previews = self.registry[ID_PREVIEW]
+        self.assertIs(previews[pform.TextAreaField],
                       fieldpreviews.textareaPreview)
 
         request = DummyRequest()
@@ -55,8 +55,8 @@ class TestFieldPreviews(PtahTestCase):
         self.assertIn('TextArea field', html)
 
     def test_linesPreview(self):
-        previews = config.get_cfg_storage(PREVIEW_ID)
-        self.assertIs(previews[form.LinesField],
+        previews = self.registry[ID_PREVIEW]
+        self.assertIs(previews[pform.LinesField],
                       fieldpreviews.linesPreview)
 
         request = DummyRequest()
@@ -64,8 +64,8 @@ class TestFieldPreviews(PtahTestCase):
         self.assertIn('Lines field', html)
 
     def test_textPreview(self):
-        previews = config.get_cfg_storage(PREVIEW_ID)
-        self.assertIs(previews[form.TextField],
+        previews = self.registry[ID_PREVIEW]
+        self.assertIs(previews[pform.TextField],
                       fieldpreviews.textPreview)
 
         request = DummyRequest()
@@ -73,8 +73,8 @@ class TestFieldPreviews(PtahTestCase):
         self.assertIn('Text field', html)
 
     def test_intPreview(self):
-        previews = config.get_cfg_storage(PREVIEW_ID)
-        self.assertIs(previews[form.IntegerField],
+        previews = self.registry[ID_PREVIEW]
+        self.assertIs(previews[pform.IntegerField],
                       fieldpreviews.intPreview)
 
         request = DummyRequest()
@@ -82,8 +82,8 @@ class TestFieldPreviews(PtahTestCase):
         self.assertIn('Integer field', html)
 
     def test_floatPreview(self):
-        previews = config.get_cfg_storage(PREVIEW_ID)
-        self.assertIs(previews[form.FloatField],
+        previews = self.registry[ID_PREVIEW]
+        self.assertIs(previews[pform.FloatField],
                       fieldpreviews.floatPreview)
 
         request = DummyRequest()
@@ -91,8 +91,8 @@ class TestFieldPreviews(PtahTestCase):
         self.assertIn('Float field', html)
 
     def test_decimalPreview(self):
-        previews = config.get_cfg_storage(PREVIEW_ID)
-        self.assertIs(previews[form.DecimalField],
+        previews = self.registry[ID_PREVIEW]
+        self.assertIs(previews[pform.DecimalField],
                       fieldpreviews.decimalPreview)
 
         request = DummyRequest()
@@ -100,8 +100,8 @@ class TestFieldPreviews(PtahTestCase):
         self.assertIn('Decimal field', html)
 
     def test_passwordPreview(self):
-        previews = config.get_cfg_storage(PREVIEW_ID)
-        self.assertIs(previews[form.PasswordField],
+        previews = self.registry[ID_PREVIEW]
+        self.assertIs(previews[pform.PasswordField],
                       fieldpreviews.passwordPreview)
 
         request = DummyRequest()
@@ -109,8 +109,8 @@ class TestFieldPreviews(PtahTestCase):
         self.assertIn('Password field', html)
 
     def test_timezonePreview(self):
-        previews = config.get_cfg_storage(PREVIEW_ID)
-        self.assertIs(previews[form.TimezoneField],
+        previews = self.registry[ID_PREVIEW]
+        self.assertIs(previews[pform.TimezoneField],
                       fieldpreviews.timezonePreview)
 
         request = DummyRequest()
@@ -144,9 +144,9 @@ class TestFieldsModule(PtahTestCase):
         res = render_view_to_response(mod, request, '', False)
         self.assertEqual(res.status, '200 OK')
 
-        from ptah.form.field import FIELD_ID
+        from pform.directives import ID_FIELD
 
-        fields = config.get_cfg_storage(FIELD_ID)
+        fields = self.registry[ID_FIELD]
 
         view = FieldsView(None, request)
         view.update()
