@@ -1,23 +1,23 @@
 """ uri resolve """
 import inspect
+import pform
 from pyramid.view import view_config
-from pyramid.httpexceptions import HTTPFound
 
 import ptah
-from ptah import form, config, manage
+from ptah import config
 from ptah.uri import ID_RESOLVER
-from ptah.manage.manage import PtahManageRoute, get_manage_url
+from ptah.manage.manage import PtahManageRoute
 
 
 @view_config(
-    'uri.html', context=PtahManageRoute, wrapper=ptah.wrap_layout(),
-    renderer='ptah.manage:templates/uri.pt')
+    name='uri.html', context=PtahManageRoute, wrapper=ptah.wrap_layout(),
+    renderer='ptah-manage:uri.lt')
 
-class UriResolver(form.Form):
+class UriResolver(pform.Form):
     """ Uri resolver form """
 
-    fields = form.Fieldset(
-        form.LinesField(
+    fields = pform.Fieldset(
+        pform.LinesField(
             'uri',
             title = 'Uri',
             description = "List of uri's",
@@ -29,11 +29,11 @@ class UriResolver(form.Form):
     def form_content(self):
         return {'uri': [self.request.GET.get('uri','')]}
 
-    @form.button('Show', actype=form.AC_PRIMARY)
+    @pform.button('Show', actype=pform.AC_PRIMARY)
     def show_handler(self):
         data, errors = self.extract()
         if errors:
-            self.message(errors, 'form-error')
+            self.add_error_message(errors)
         else:
             self.uri = data['uri']
 
