@@ -7,10 +7,11 @@ from collections import OrderedDict
 from zope import interface
 from zope.interface.interface import InterfaceClass
 from pyramid.compat import configparser
-from pyramid.interfaces import PHASE1_CONFIG
+
+import pform as form
 
 import ptah
-from ptah import uri, form, config
+from ptah import uri, config
 from ptah.sqlautils import JsonType
 from ptah.config import StopException
 
@@ -85,8 +86,7 @@ def init_settings(pconfig, cfg=None, section=configparser.DEFAULTSECT):
       config.ptah_init_settings()
 
     """
-    registry = pconfig.registry
-    settings = config.get_cfg_storage(SETTINGS_OB_ID,pconfig.registry,Settings)
+    settings = config.get_cfg_storage(SETTINGS_OB_ID, pconfig.registry,Settings)
 
     if settings.initialized:
         raise RuntimeError(
@@ -127,7 +127,7 @@ def register_settings(name, *fields, **kw):
     """Register settings group.
 
     :param name: Name of settings group
-    :param fields: List of :py:class:`ptah.form.Field` objects
+    :param fields: List of :py:class:`pform.Field` objects
 
     """
     iname = name
@@ -152,7 +152,7 @@ def register_settings(name, *fields, **kw):
     info = config.DirectiveInfo()
     discr = (ID_SETTINGS_GROUP, name)
     intr = config.Introspectable(
-        ID_SETTINGS_GROUP, discr, group.__title__, ID_SETTINGS_GROUP)
+        ID_SETTINGS_GROUP, discr, group.__title__, 'ptah-settingsgroup')
     intr['name'] = name
     intr['group'] = group
     intr['codeinfo'] = info.codeinfo
@@ -237,7 +237,8 @@ class Settings(object):
                 if group[fname] == field.default and not default:
                     continue
 
-                result['{0}.{1}'.format(name,fname)] = field.dumps(group[fname])
+                result['{0}.{1}'.format(name,fname)] = \
+                                    ptah.json.dumps(group[fname])
 
         return result
 
@@ -277,7 +278,15 @@ class Group(OrderedDict):
                 value = self.get(field.name)
             else:
                 try:
-                    value = field.loads(value)
+
+                    try:
+                        value = ptah.json.loads(value)
+                    except:
+                        if not value.startswith('"'):
+                            value = '"{0}"'.format(value)
+                        value = value.replace('\n', '\\n')
+                        value = ptah.json.loads(value)
+
                     field.validate(value)
 
                     if field.preparer is not None:
@@ -342,7 +351,7 @@ class Group(OrderedDict):
                     continue
 
                 rec = SettingRecord(name='{0}.{1}'.format(name, fname),
-                                    value = field.dumps(value))
+                                    value = ptah.json.dumps(value))
             else:
                 rec = SettingRecord(
                     name='{0}.{1}'.format(name, fname),
