@@ -1,25 +1,23 @@
 """ base class """
 import sys
-import sqlalchemy
 import transaction
-import pkg_resources
 from zope.interface import directlyProvides
 from pyramid import testing
-from pyramid.interfaces import \
-     IRequest, IAuthenticationPolicy, IAuthorizationPolicy
+from pyramid.interfaces import IRequest
 from pyramid.interfaces import IRouteRequest
-from pyramid.view import render_view, render_view_to_response
+from pyramid.interfaces import IRequestExtensions
+from pyramid.view import render_view_to_response
 from pyramid.path import package_name
-from pyramid.authorization import ACLAuthorizationPolicy
-from pyramid.authentication import AuthTktAuthenticationPolicy
+from player.renderer import render
 
 if sys.version_info[:2] == (2, 6): # pragma: no cover
+    import unittest2 as unittest
     from unittest2 import TestCase
 else:
+    import unittest
     from unittest import TestCase
 
 import ptah
-from ptah import config
 
 
 class PtahTestCase(TestCase):
@@ -39,13 +37,26 @@ class PtahTestCase(TestCase):
         'SCRIPT_NAME': '',
         'PATH_INFO': '/',}
 
-    def make_request(self, environ=None, request_iface=IRequest, **kwargs):
+    def make_request(self, registry=None, environ=None,
+                     request_iface=IRequest, **kwargs):
+        if registry is None:
+            registry = self.registry
         if environ is None:
             environ=self._environ
         request = testing.DummyRequest(environ=environ, **kwargs)
         request.request_iface = IRequest
+        request.registry = registry
+        request._set_extensions(registry.getUtility(IRequestExtensions))
         return request
 
+    def init_request_extensions(self, registry):
+        from pyramid.config.factories import _RequestExtensions
+
+        exts = registry.queryUtility(IRequestExtensions)
+        if exts is None:
+            exts = _RequestExtensions()
+            registry.registerUtility(exts, IRequestExtensions)
+
     def init_ptah(self, *args, **kw):
         self.registry.settings.update(self._settings)
         self.config.include('ptah')
@@ -55,11 +66,11 @@ class PtahTestCase(TestCase):
 
         pkg = package_name(sys.modules[self.__class__.__module__])
         if pkg != 'ptah':
-            packages = []
             parts = self.__class__.__module__.split('.')
             for l in range(len(parts)):
                 pkg = '.'.join(parts[:l+1])
-                if pkg == 'ptah' or pkg.startswith('ptah.') or pkg in self._includes:
+                if pkg == 'ptah' or pkg.startswith('ptah.') or \
+                       pkg in self._includes:
                     continue # pragma: no cover
                 try:
                     self.config.include(pkg)
@@ -90,12 +101,22 @@ class PtahTestCase(TestCase):
             ptah.manage.set_access_manager(trusted)
 
     def init_pyramid(self):
-        self.request = request = self.make_request()
-        self.config = testing.setUp(
-            request=request, settings=self._settings, autocommit=False)
+        self.config = testing.setUp(settings=self._settings, autocommit=False)
         self.config.get_routes_mapper()
+        self.init_request_extensions(self.config.registry)
         self.registry = self.config.registry
-        self.request.registry = self.registry
+
+        self.config.include('pform')
+        self.config.include('player')
+        self.config.include('pyramid_amdjs')
+
+        self.request = self.make_request()
+        def set_ext():
+            self.request._set_extensions(
+                self.registry.getUtility(IRequestExtensions))
+
+        self.config.action(id(self), callable=set_ext)
+        self.config.begin(self.request)
 
     def setUp(self):
         self.init_pyramid()
