@@ -1,9 +1,8 @@
 import os
+import pform
 import shutil
 import tempfile
 from pyramid.compat import bytes_
-from zope.interface.interface import InterfaceClass
-from zope.interface.interfaces import IObjectEvent
 
 import ptah
 from ptah.settings import Settings
@@ -32,7 +31,7 @@ class BaseTesting(PtahTestCase):
 class TestSettingsResolver(BaseTesting):
 
     def test_settings_uri_resolver(self):
-        node = ptah.form.TextField(
+        node = pform.TextField(
             'node',
             default = 'test')
 
@@ -53,7 +52,7 @@ class TestSettingsResolver(BaseTesting):
 class TestSettings(BaseTesting):
 
     def test_settings_no_default(self):
-        field = ptah.form.TextField('node')
+        field = pform.TextField('node')
 
         self.assertRaises(
             ptah.config.StopException,
@@ -64,7 +63,7 @@ class TestSettings(BaseTesting):
             )
 
     def test_settings_group_basics(self):
-        node = ptah.form.TextField(
+        node = pform.TextField(
             'node',
             default = 'test')
 
@@ -83,7 +82,7 @@ class TestSettings(BaseTesting):
         self.assertEqual(group.get('node'), '12345')
 
     def test_settings_group_uninitialized(self):
-        node = ptah.form.TextField(
+        node = pform.TextField(
             'node',
             default = 'test')
 
@@ -98,10 +97,10 @@ class TestSettings(BaseTesting):
         self.assertEqual(group.get('node'), 'test')
 
     def test_settings_group_extract(self):
-        node1 = ptah.form.TextField(
+        node1 = pform.TextField(
             'node1', default = 'test1')
 
-        node2 = ptah.form.TextField(
+        node2 = pform.TextField(
             'node2', default = 'test2')
 
         ptah.register_settings('group', node1, node2)
@@ -119,7 +118,7 @@ class TestSettings(BaseTesting):
         self.assertEqual(data['node2'], 'value')
 
     def test_settings_get_settings_pyramid(self):
-        node = ptah.form.TextField(
+        node = pform.TextField(
             'node',
             default = 'test')
 
@@ -137,7 +136,7 @@ class TestSettings(BaseTesting):
         self.assertIn(node, grp.__fields__.values())
 
     def test_settings_register_simple(self):
-        node = ptah.form.TextField(
+        node = pform.TextField(
             'node',
             default = 'test')
 
@@ -163,9 +162,9 @@ class TestSettings(BaseTesting):
 
     def test_settings_group_validation(self):
         def validator(node, appstruct):
-            raise ptah.form.Invalid(node['node'], 'Error')
+            raise pform.Invalid(node['node'], 'Error')
 
-        node = ptah.form.TextField(
+        node = pform.TextField(
             'node',
             default = 'test')
 
@@ -182,16 +181,16 @@ class TestSettings(BaseTesting):
 
     def test_settings_group_multiple_validation(self):
         def validator1(fs, appstruct):
-            raise ptah.form.Invalid(fs['node1'], 'Error1')
+            raise pform.Invalid(fs['node1'], 'Error1')
 
         def validator2(fs, appstruct):
-            raise ptah.form.Invalid(fs['node2'], 'Error2')
+            raise pform.Invalid(fs['node2'], 'Error2')
 
-        node1 = ptah.form.TextField(
+        node1 = pform.TextField(
             'node1',
             default = 'test')
 
-        node2 = ptah.form.TextField(
+        node2 = pform.TextField(
             'node2',
             default = 'test')
 
@@ -208,11 +207,11 @@ class TestSettings(BaseTesting):
         self.assertEqual(err.msg, {'group3': ['Error1', 'Error2']})
 
     def test_settings_export(self):
-        field1 = ptah.form.TextField(
+        field1 = pform.TextField(
             'node1',
             default = 'test')
 
-        field2 = ptah.form.TextField(
+        field2 = pform.TextField(
             'node2',
             default = 'test1')
 
@@ -239,11 +238,11 @@ class TestSettings(BaseTesting):
         self.assertEqual(data['group4.node2'], '"changed"')
 
     def _create_default_group(self):
-        node1 = ptah.form.TextField(
+        node1 = pform.TextField(
             'node1',
             default = 'default1')
 
-        node2 = ptah.form.IntegerField(
+        node2 = pform.IntegerField(
             'node2',
             default = 10)
 
@@ -277,7 +276,7 @@ class TestSettings(BaseTesting):
         self.assertEqual(group.__fields__['node2'].default, 30)
 
     def test_settings_load_rawdata_with_errors_in_rawdata(self):
-        group = self._create_default_group()
+        self._create_default_group()
 
         self.assertRaises(
             ptah.config.StopException,
@@ -285,7 +284,7 @@ class TestSettings(BaseTesting):
             self.config, {10: 'value'})
 
     def test_settings_load_defaults_rawdata_with_errors_in_values(self):
-        node = ptah.form.LinesField(
+        node = pform.FloatField(
             'node1',
             default = ())
 
@@ -355,7 +354,6 @@ class TestSettingsInitialization(BaseTesting):
 
         sm = self.config.registry
 
-        events = []
         err_tp = TypeError()
 
         def h1(ev):
@@ -384,11 +382,11 @@ class TestSettingsInitialization(BaseTesting):
     def test_settings_initialize_load_defaults(self):
         from ptah.settings import init_settings
 
-        node1 = ptah.form.TextField(
+        node1 = pform.TextField(
             'node1',
             default = 'default1')
 
-        node2 = ptah.form.TextField(
+        node2 = pform.TextField(
             'node2',
             default = 10)
 
@@ -404,7 +402,7 @@ class TestSettingsInitialization(BaseTesting):
     def test_settings_initialize_load_preparer(self):
         from ptah.settings import init_settings
 
-        node1 = ptah.form.TextField(
+        node1 = pform.TextField(
             'node',
             default = 'default1',
             preparer = lambda s: s.lower())
@@ -420,11 +418,11 @@ class TestSettingsInitialization(BaseTesting):
     def test_settings_initialize_load_partly_defaults(self):
         from ptah.settings import init_settings
 
-        node1 = ptah.form.TextField(
+        node1 = pform.TextField(
             'node1',
             default = 'default1')
 
-        node2 = ptah.form.TextField(
+        node2 = pform.TextField(
             'node2',
             default = 10)
 
@@ -445,11 +443,11 @@ class TestSettingsInitialization(BaseTesting):
         f.write(bytes_('[DEFAULT]\ngroup.node1 = value\n\n','ascii'))
         f.close()
 
-        node1 = ptah.form.TextField(
+        node1 = pform.TextField(
             'node1',
             default = 'default1')
 
-        node2 = ptah.form.IntegerField(
+        node2 = pform.IntegerField(
             'node2',
             default = 10)
 
@@ -467,11 +465,11 @@ class TestSettingsInitialization(BaseTesting):
 class TestDBSettingsBase(PtahTestCase):
 
     def _make_grp(self):
-        node1 = ptah.form.TextField(
+        node1 = pform.TextField(
             'node1',
             default = 'test')
 
-        node2 = ptah.form.IntegerField(
+        node2 = pform.IntegerField(
             'node2',
             default = 50)
 
